summaryrefslogtreecommitdiffstats
path: root/scripts/lib
diff options
context:
space:
mode:
authorMichael Olbrich <m.olbrich@pengutronix.de>2015-10-15 10:28:52 +0200
committerMichael Olbrich <m.olbrich@pengutronix.de>2015-10-15 10:28:52 +0200
commit6861343e6d89d50e471a34b8be98b41f90035962 (patch)
treef7f07261010a3cbb12e3713e73de70bb9f1162ba /scripts/lib
parente5576bc804bc485e73f722ba57a36c093201d92a (diff)
downloadptxdist-6861343e6d89d50e471a34b8be98b41f90035962.tar.gz
ptxdist-6861343e6d89d50e471a34b8be98b41f90035962.tar.xz
ptxd_make_world_extract: do nothing if <PKG>_DIR is not defined
Signed-off-by: Michael Olbrich <m.olbrich@pengutronix.de>
Diffstat (limited to 'scripts/lib')
-rw-r--r--scripts/lib/ptxd_make_world_extract.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/scripts/lib/ptxd_make_world_extract.sh b/scripts/lib/ptxd_make_world_extract.sh
index 081e7f5de..970fb0b8d 100644
--- a/scripts/lib/ptxd_make_world_extract.sh
+++ b/scripts/lib/ptxd_make_world_extract.sh
@@ -15,8 +15,8 @@
ptxd_make_world_extract() {
ptxd_make_world_init || return
- if [ -z "${pkg_url}" -a -z "${pkg_src}" ]; then
- # no <PKG>_URL and no <PKG>_SOURCE -> assume the package has nothing to extract.
+ if [ -z "${pkg_url}" -a -z "${pkg_src}" -o -z "${pkg_dir}" ]; then
+ # no <PKG>_URL and no <PKG>_SOURCE or no <PKG>_DIR -> assume the package has nothing to extract.
return
fi